aboutsummaryrefslogtreecommitdiff
path: root/src/runtime/CL/CLTuner.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/runtime/CL/CLTuner.cpp')
-rw-r--r--src/runtime/CL/CLTuner.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/runtime/CL/CLTuner.cpp b/src/runtime/CL/CLTuner.cpp
index f3300d3f83..7f5be86833 100644
--- a/src/runtime/CL/CLTuner.cpp
+++ b/src/runtime/CL/CLTuner.cpp
@@ -42,8 +42,8 @@ void CLTuner::tune_kernel(ICLKernel &kernel)
// Get the configuration ID from the kernel
const std::string &config_id = kernel.config_id();
- // Check if we need to find the Optimal LWS. If config_id is empty, the kernel does not require to be tuned
- if(config_id != "")
+ // Check if we need to find the Optimal LWS. If config_id is equal to default_config_id, the kernel does not require to be tuned
+ if(config_id != arm_compute::default_config_id)
{
auto p = _lws_table.find(config_id);